'use strict';

var _nodeSchedule = require('node-schedule');

var _nodeSchedule2 = _interopRequireDefault(_nodeSchedule);

var _winston = require('winston');

var _winston2 = _interopRequireDefault(_winston);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var sendMail = require('sendmail')({ silent: true });

_winston2.default.setLevels({
    debug: 0,
    info: 1,
    silly: 2,
    warn: 3,
    error: 4
});

_winston2.default.addColors({
    debug: 'green',
    info: 'cyan',
    silly: 'magenta',
    warn: 'yellow',
    error: 'red'
});

_winston2.default.remove(_winston2.default.transports.Console);
_winston2.default.add(_winston2.default.transports.Console, {
    level: 'error',
    colorize: true,
    prettyPrint: true
});

_winston2.default.add(_winston2.default.transports.File, {
    level: 'error',
    filename: 'EPUB-search.log',
    maxsize: 7340032, //7MB
    maxFiles: 1,
    colorize: true,
    prettyPrint: true
});

/*

*    *    *    *    *    *
┬    ┬    ┬    ┬    ┬    ┬
│    │    │    │    │    |
│    │    │    │    │    └ day of week (0 - 7) (0 or 7 is Sun)
│    │    │    │    └───── month (1 - 12)
│    │    │    └────────── day of month (1 - 31)
│    │    └─────────────── hour (0 - 23)
│    └──────────────────── minute (0 - 59)
└───────────────────────── second (0 - 59, OPTIONAL)

*/
var rule = new _nodeSchedule2.default.RecurrenceRule();
rule.dayOfWeek = [0, 1, 2, 3, 4, 5, 6];
rule.hour = 10;
rule.minute = 0;

_nodeSchedule2.default.scheduleJob(rule, function () {
    sendMail({
        from: 'no-reply@epub-search.com',
        to: 'lars.voigt@dzb.de',
        subject: 'EPUB-search.log',
        html: '',
        attachments: [{ // define custom content type for the attachment
            filename: 'EPUB-search.log',
            path: './EPUB-search.log' // stream this file
        }]
    }, function (err, reply) {
        _winston2.default.log('error', err && err.stack);
    });
});

module.exports = _winston2.default;